@@ -1,3 +1,3 @@
 from .message import Message
 from .message_thread import MessageThread
-from .user import User
+from .user import User, OKCupydUser
