@@ -1,7 +1,5 @@
 import logging
 
-from lxml import html
-
 from . import util
 from .xpath import xpb
 
@@ -9,62 +7,6 @@ from .xpath import xpb
 log = logging.getLogger(__name__)
 
 
-class QuestionProcessor(object):
-
-    _page_data_xpb = xpb.div.with_class('pages_data')
-    _current_page_xpb = _page_data_xpb.input(id='questions_pages_page').\
-                        select_attribute_('value')
-    _total_page_xpb = _page_data_xpb.input(id='questions_pages_total').\
-                      select_attribute_('value')
-
-    def __init__(self, question_class):
-        self.question_class = question_class
-
-    def _current_page(self, tree):
-        return int(self._current_page_xpb.one_(tree))
-
-    def _page_count(self, tree):
-        return int(self._total_page_xpb.one_(tree))
-
-    def _are_pages_left(self, tree):
-        return self._current_page(tree) < self._page_count(tree)
-
-    _question_xpb = xpb.div.with_class('question')
-
-    def process(self, text_response):
-        tree = html.fromstring(text_response)
-        for question_element in self._question_xpb.apply_(tree):
-            yield self.question_class(question_element)
-        if not self._are_pages_left(tree):
-            # This is pretty gross: Part of the processor protocol
-            # is that if StopIteration is yielded, the loop above
-            # will be terminated. No easy way around this short
-            # Of making bigger objects or abstracting less.
-            yield StopIteration
-
-
-class QuestionHTMLFetcher(object):
-
-    @classmethod
-    def from_username(cls, session, username, **kwargs):
-        return cls(session, u'profile/{0}/questions'.format(username), **kwargs)
-
-    def __init__(self, session, uri, **additional_parameters):
-        self._session = session
-        self._uri = uri
-        self._additional_parameters = additional_parameters
-
-    def _query_params(self, start_at):
-        parameters = {'low': start_at, 'leanmode': 1}
-        parameters.update(self._additional_parameters)
-        return parameters
-
-    def fetch(self, start_at):
-        response = self._session.okc_get(self._uri,
-                                         params=self._query_params(start_at))
-        return response.content.decode('utf8')
-
-
 class BaseQuestion(object):
 
     def __init__(self, question_element):
@@ -89,8 +31,9 @@ class BaseQuestion(object):
 
 
 class Question(BaseQuestion):
+    """Represent a question answered by a user other than the logged in user."""
 
-    def return_none_if_broken(function):
+    def return_none_if_unanswered(function):
         def wrapped(self):
             if self.answered:
                 return function(self)
@@ -110,32 +53,32 @@ class Question(BaseQuestion):
             pass
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def their_answer(self):
         return self._their_answer_span.text_content().strip()
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def my_answer(self):
         return self._my_answer_span.text_content().strip()
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def their_answer_matches(self):
         return 'not_accepted' not in self._their_answer_span.attrib['class']
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def my_answer_matches(self):
         return 'not_accepted' not in self._my_answer_span.attrib['class']
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def their_note(self):
         return self._their_note_span.text_content().strip()
 
     @util.cached_property
-    @return_none_if_broken
+    @return_none_if_unanswered
     def my_note(self):
         return self._my_note_span.text_content().strip()
 
@@ -143,6 +86,7 @@ class Question(BaseQuestion):
 
 
 class UserQuestion(BaseQuestion):
+    """Represent a question answered by the logged in user."""
 
     _answer_option_xpb = xpb.ul.with_class('self_answers').li
     _explanation_xpb = xpb.div.with_class('your_explanation').p.with_class('value')
@@ -198,21 +142,13 @@ class AnswerOption(object):
         )
 
 
-def QuestionFetcher(session, username, question_class=Question,
-                    is_user=False, **kwargs):
-    if is_user:
-        question_class = UserQuestion
-    return util.FetchMarshall(
-        QuestionHTMLFetcher.from_username(session, username, **kwargs),
-        QuestionProcessor(question_class)
-    )
-
-
 importances = ('not_important', 'little_important', 'somewhat_important',
                'very_important', 'mandatory')
 
 
 class Questions(object):
+    """Interface to accessing and answering questions belonging to the logged
+    in user."""
 
     headers = {
         'accept': 'application/json, text/javascript, */*; q=0.01',
@@ -237,10 +173,10 @@ class Questions(object):
     def __init__(self, session, importances=importances, user_id=None):
         self.importance_name_to_fetchable = {}
         for importance in importances:
-            fetchable = util.Fetchable(util.FetchMarshall(
+            fetchable = util.Fetchable.fetch_marshall(
                 QuestionHTMLFetcher(session, 'questions', **{importance: 1}),
                 QuestionProcessor(UserQuestion)
-            ))
+            )
             self.importance_name_to_fetchable[importance] = fetchable
             setattr(self, importance, fetchable)
         self._session = session
@@ -252,6 +188,14 @@ class Questions(object):
         return self._session.get_current_user_profile().id
 
     def respond_from_user_question(self, user_question, importance):
+        """Respond to a question in exactly the way that is described by
+        the given user_question.
+        :param user_question: The user question to respond with.
+        :type user_question: :class:`.UserQuestion`
+        :param importance: The importance that should be used in responding to
+                           the question.
+        :type importance: int
+        """
         user_response_ids = [option.id
                              for option in user_question.answer_options
                              if option.is_users]
@@ -296,3 +240,46 @@ class Questions(object):
         return self._session.okc_post(
             'questions', data={'clear_all': 1}, headers=self.headers
         )
+
+
+_page_data_xpb = xpb.div.with_class('pages_data')
+_current_page_xpb = _page_data_xpb.input(id='questions_pages_page').\
+                    select_attribute_('value')
+_total_page_xpb = _page_data_xpb.input(id='questions_pages_total').\
+                  select_attribute_('value')
+_question_xpb = xpb.div.with_class('question')
+def QuestionProcessor(question_class):
+    return util.PaginationProcessor(question_class, _question_xpb,
+                                    _current_page_xpb, _total_page_xpb)
+
+
+class QuestionHTMLFetcher(object):
+
+    @classmethod
+    def from_username(cls, session, username, **kwargs):
+        return cls(session, u'profile/{0}/questions'.format(username), **kwargs)
+
+    def __init__(self, session, uri, **additional_parameters):
+        self._session = session
+        self._uri = uri
+        self._additional_parameters = additional_parameters
+
+    def _query_params(self, start_at):
+        parameters = {'low': start_at, 'leanmode': 1}
+        parameters.update(self._additional_parameters)
+        return parameters
+
+    def fetch(self, start_at):
+        response = self._session.okc_get(self._uri,
+                                         params=self._query_params(start_at))
+        return response.content.decode('utf8')
+
+
+def QuestionFetcher(session, username, question_class=Question,
+                    is_user=False, **kwargs):
+    if is_user:
+        question_class = UserQuestion
+    return util.FetchMarshall(
+        QuestionHTMLFetcher.from_username(session, username, **kwargs),
+        QuestionProcessor(question_class)
+    )
